@@ -1,10 +1,9 @@
 use std::time::Duration;
-use stretto::{AsyncCache, DefaultKeyBuilder};
+use stretto::AsyncCache;
 
 #[tokio::main]
 async fn main() {
-    let c: AsyncCache<&str, &str, DefaultKeyBuilder> =
-        AsyncCache::new(12960, 1e6 as i64, DefaultKeyBuilder::default()).unwrap();
+    let c: AsyncCache<&str, &str> = AsyncCache::new(12960, 1e6 as i64).unwrap();
 
     // set a value with a cost of 1
     c.insert("a", "a", 1).await;
